Index: /waeup/branches/ulif-namespace/src/waeup/sirp/README.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/README.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/README.txt	(revision 4920)
@@ -1,4 +1,4 @@
-The waeup package
-********************
+The waeup.sirp package
+**********************
 
 :Test-Layer: unit
@@ -13,5 +13,5 @@
 
   >>> import grok
-  >>> grok.testing.grok('waeup')
+  >>> grok.testing.grok('waeup.sirp')
 
 Universities
@@ -23,8 +23,8 @@
 We can easily create universities::
 
-  >>> from waeup.app import University
+  >>> from waeup.sirp.app import University
   >>> u = University()
   >>> u
-  <waeup.app.University object at 0x...>
+  <waeup.sirp.app.University object at 0x...>
 
 Universities have a name.
@@ -37,19 +37,19 @@
 
   >>> u['faculties']
-  <waeup.university.facultycontainer.FacultyContainer object at 0x...>
+  <waeup.sirp.university.facultycontainer.FacultyContainer object at 0x...>
 
   >>> u['students']
-  <waeup.student.studentcontainer.StudentContainer object at 0x...>
+  <waeup.sirp.student.studentcontainer.StudentContainer object at 0x...>
 
   >>> u['hostels']
-  <waeup.hostel.hostelcontainer.HostelContainer object at 0x...>
+  <waeup.sirp.hostel.hostelcontainer.HostelContainer object at 0x...>
 
 We can export universities. For this we lookup an appropriate exporter
 first::
 
-  >>> from waeup.interfaces import IWAeUPExporter
+  >>> from waeup.sirp.interfaces import IWAeUPExporter
   >>> exporter = IWAeUPExporter(u)
   >>> exporter
-  <waeup.utils.importexport.Exporter object at 0x...>
+  <waeup.sirp.utils.importexport.Exporter object at 0x...>
 
 Now we can trigger the export::
@@ -62,5 +62,5 @@
 memory file::
 
-  >>> from waeup.interfaces import IWAeUPXMLExporter
+  >>> from waeup.sirp.interfaces import IWAeUPXMLExporter
   >>> exporter = IWAeUPXMLExporter(u)
   >>> f = exporter.export()
@@ -84,8 +84,8 @@
 We can create faculties easily::
 
-  >>> from waeup.university.faculty import Faculty
+  >>> from waeup.sirp.university.faculty import Faculty
   >>> f = Faculty()
   >>> f
-  <waeup.university.faculty.Faculty object at 0x...>
+  <waeup.sirp.university.faculty.Faculty object at 0x...>
 
 Also faculties want to be named::
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/__init__.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/__init__.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/__init__.py	(revision 4920)
@@ -1,4 +1,4 @@
 import grok
-from waeup.interfaces import IWAeUPObject
+from waeup.sirp.interfaces import IWAeUPObject
 from zope.annotation.attribute import AttributeAnnotations
 from zope.annotation.interfaces import IAnnotations
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/app.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/app.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/app.py	(revision 4920)
@@ -6,9 +6,9 @@
 from zope.component import createObject
 
-from waeup.interfaces import (IUniversity, ICSVDataReceivers, IDataCenter,
+from waeup.sirp.interfaces import (IUniversity, ICSVDataReceivers, IDataCenter,
                               IDataCenterStorageMovedEvent)
-from waeup.authentication import setup_authentication
-from waeup.datacenter import DataCenter
-from waeup.users import UserContainer
+from waeup.sirp.authentication import setup_authentication
+from waeup.sirp.datacenter import DataCenter
+from waeup.sirp.users import UserContainer
 
 class University(grok.Application, grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/app.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/app.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/app.txt	(revision 4920)
@@ -1,8 +1,8 @@
-:mod:`waeup.app` -- central components for a WAeUP portal
-*********************************************************
+:mod:`waeup.sirp.app` -- central components for a WAeUP portal
+**************************************************************
 
 :Test-Layer: unit
 
-.. module:: waeup.app
+.. module:: waeup.sirp.app
 
 .. class:: University
@@ -20,5 +20,5 @@
      An arbitrary object containing "faculties". In the case of
      `University` it is a container of type
-     `waeup.interfaces.IFacultyContainer`.
+     `waeup.sirp.interfaces.IFacultyContainer`.
 
 
@@ -39,14 +39,14 @@
 instance:
 
-    >>> from waeup.app import University
+    >>> from waeup.sirp.app import University
     >>> myuniversity = University()
     >>> myuniversity
-    <waeup.app.University object at 0x...>
+    <waeup.sirp.app.University object at 0x...>
 
 Instances of `University` comply with the interface
-`waeup.interfaces.IUniversity`:
+`waeup.sirp.interfaces.IUniversity`:
 
     >>> from zope.interface.verify import verifyClass
-    >>> from waeup.interfaces import IUniversity
+    >>> from waeup.sirp.interfaces import IUniversity
     >>> verifyClass(IUniversity, University)
     True
@@ -55,5 +55,5 @@
 interface:
 
-    >>> from waeup.app import University
+    >>> from waeup.sirp.app import University
     >>> myuniversity = University()
     >>> myuniversity.name
@@ -61,3 +61,3 @@
 
     >>> myuniversity['faculties']
-    <waeup.university.facultycontainer.FacultyContainer object at 0x...>
+    <waeup.sirp.university.facultycontainer.FacultyContainer object at 0x...>
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/authentication.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/authentication.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/authentication.py	(revision 4920)
@@ -10,6 +10,6 @@
 from zope.securitypolicy.interfaces import IPrincipalRoleManager
 from zope.securitypolicy.principalrole import principalRoleManager
-from waeup.interfaces import IUserAccount
-import waeup.permissions
+from waeup.sirp.interfaces import IUserAccount
+import waeup.sirp.permissions
 
 def setup_authentication(pau):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/browser/__init__.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/browser/__init__.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/browser/__init__.py	(revision 4920)
@@ -1,3 +1,3 @@
-from waeup.browser.layout import (WAeUPPage, WAeUPLayout, WAeUPDisplayFormPage,
-                                  WAeUPEditFormPage, WAeUPAddFormPage,
-                                  NullValidator)
+from waeup.sirp.browser.layout import (
+    WAeUPPage, WAeUPLayout, WAeUPDisplayFormPage, WAeUPEditFormPage,
+    WAeUPAddFormPage, NullValidator)
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/browser/breadcrumbs.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/browser/breadcrumbs.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/browser/breadcrumbs.py	(revision 4920)
@@ -6,6 +6,6 @@
 from zope.publisher.browser import TestRequest
 
-from waeup import interfaces
-from waeup.browser.interfaces import (IBreadcrumb, IBreadcrumbIgnorable,
+from waeup.sirp import interfaces
+from waeup.sirp.browser.interfaces import (IBreadcrumb, IBreadcrumbIgnorable,
                                       IBreadcrumbContainer)
         
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/browser/layout.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/browser/layout.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/browser/layout.py	(revision 4920)
@@ -4,5 +4,5 @@
 from hurry import yui
 from megrok.layout import Page, Layout, EditForm, DisplayForm, AddForm
-from waeup.interfaces import IWAeUPObject
+from waeup.sirp.interfaces import IWAeUPObject
 from z3c.flashmessage.interfaces import IMessageSource
 from zope.component import queryUtility, ComponentLookupError
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/browser/pages.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/browser/pages.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/browser/pages.py	(revision 4920)
@@ -12,15 +12,15 @@
 from hurry.query.query import Query, Text
 from hurry.workflow.interfaces import NoTransitionAvailableError
-from waeup.browser import (WAeUPPage, WAeUPEditFormPage, WAeUPAddFormPage,
+from waeup.sirp.browser import (WAeUPPage, WAeUPEditFormPage, WAeUPAddFormPage,
                            WAeUPDisplayFormPage, NullValidator)
-from waeup.catalog import search, search_context
-from waeup.datacenter import Import
-from waeup.interfaces import (IUniversity, IWAeUPObject, IUserContainer,
+from waeup.sirp.catalog import search, search_context
+from waeup.sirp.datacenter import Import
+from waeup.sirp.interfaces import (IUniversity, IWAeUPObject, IUserContainer,
                               IUserAccount, IFacultyContainer, IDataCenter,
                               IFaculty, IDepartment, ICourse, ICertificate,
                               ICertificateCourse, IWAeUPXMLImporter,
                               IWAeUPXMLExporter)
-from waeup.widgets.interfaces import ITableProvider
-from waeup.utils.helpers import getName
+from waeup.sirp.widgets.interfaces import ITableProvider
+from waeup.sirp.utils.helpers import getName
 from zope import schema
 from zope.app.security.interfaces import (IAuthentication,
@@ -32,5 +32,5 @@
 from zope.session.interfaces import ISession
 
-from waeup.interfaces import IBatchProcessor
+from waeup.sirp.interfaces import IBatchProcessor
 from zope.component import getAllUtilitiesRegisteredFor
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/browser/viewlets.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/browser/viewlets.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/browser/viewlets.py	(revision 4920)
@@ -6,10 +6,10 @@
 from zope.component import getMultiAdapter
 from zope.location.interfaces import ISite
-from waeup.browser.pages import (UniversityPage, FacultyContainerPage,
+from waeup.sirp.browser.pages import (UniversityPage, FacultyContainerPage,
                                  DatacenterPage, FacultyPage, DepartmentPage,
                                  CoursePage, CertificatePage,
                                  CertificateCoursePage)
-from waeup.browser.interfaces import IBreadcrumbContainer
-from waeup.interfaces import (IUniversity, IWAeUPObject, IWAeUPXMLExporter,
+from waeup.sirp.browser.interfaces import IBreadcrumbContainer
+from waeup.sirp.interfaces import (IUniversity, IWAeUPObject, IWAeUPXMLExporter,
                               IWAeUPXMLImporter, IFacultyContainer, IFaculty,
                               IDepartment, ICourse, ICertificate,
@@ -164,5 +164,5 @@
             
 #
-# waeup.app.University viewlets...
+# waeup.sirp.app.University viewlets...
 #
 class Login(grok.Viewlet):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/catalog.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/catalog.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/catalog.py	(revision 4920)
@@ -4,7 +4,7 @@
 from hurry.query.query import Query, Text
 from hurry.query import Eq
-from waeup.app import University
-from waeup.interfaces import ICourse, ICertificateCourse
-from waeup.student.interfaces import IStudent
+from waeup.sirp.app import University
+from waeup.sirp.interfaces import ICourse, ICertificateCourse
+from waeup.sirp.student.interfaces import IStudent
 from zope.app.catalog.interfaces import ICatalog
 from zope.app.intid.interfaces import IIntIds
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/README.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/README.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/README.txt	(revision 4920)
@@ -1,8 +1,8 @@
-:mod:`waeup.csvfile` -- generic support for handling CSV files
-**************************************************************
+:mod:`waeup.sirp.csvfile` -- generic support for handling CSV files
+*******************************************************************
 
 :Test-Layer: unit
 
-.. module:: waeup.csvfile
+.. module:: waeup.sirp.csvfile
    :synopsis: generic support for handling CSV files.
 
@@ -10,5 +10,5 @@
 .. note::
 
-   This version of the :mod:`waeup.csvfile` module doesn't support
+   This version of the :mod:`waeup.sirp.csvfile` module doesn't support
    Unicode input.  Also, there are currently some issues regarding
    ASCII NUL characters.  Accordingly, all input should be UTF-8 or
@@ -125,5 +125,5 @@
    The string can be uppercase, lowercase or mixed:
 
-     >>> from waeup.csvfile import toBool
+     >>> from waeup.sirp.csvfile import toBool
      >>> toBool('y')
      True
@@ -149,9 +149,9 @@
 =============
 
-To initialize the whole framework we have to grok the :mod:`waeup`
+To initialize the whole framework we have to grok the :mod:`waeup.sirp`
 package first:
 
     >>> import grok
-    >>> grok.testing.grok('waeup')
+    >>> grok.testing.grok('waeup.sirp')
 
 Create a file:
@@ -168,12 +168,12 @@
 object out of a path string:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
     >>> src = ICSVFile(path)
     >>> src
-    <waeup.csvfile.csvfile.CSVFile object at 0x...>
+    <waeup.sirp.csvfile.csvfile.CSVFile object at 0x...>
 
 Create a receiver:
 
-    >>> from waeup.csvfile.interfaces import ICSVDataReceiver
+    >>> from waeup.sirp.csvfile.interfaces import ICSVDataReceiver
     >>> class Receiver(object):
     ...   grok.implements(ICSVDataReceiver)
@@ -186,11 +186,11 @@
 
     >>> from zope.component import getMultiAdapter
-    >>> from waeup.csvfile.interfaces import ICSVDataConnector
+    >>> from waeup.sirp.csvfile.interfaces import ICSVDataConnector
     >>> conn = getMultiAdapter((src, recv), ICSVDataConnector)
     Traceback (most recent call last):
     ...
-    ComponentLookupError: ((<waeup.csvfile.csvfile.CSVFile object at 0x...>, 
+    ComponentLookupError: ((<waeup.sirp.csvfile.csvfile.CSVFile object at 0x...>, 
                             <Receiver object at 0x...>),
-        <InterfaceClass waeup.csvfile.interfaces.ICSVDataConnector>, u'')
+        <InterfaceClass waeup.sirp.csvfile.interfaces.ICSVDataConnector>, u'')
 
 Okay, create a connector:
@@ -241,8 +241,8 @@
 for an adapter to the path string:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
     >>> wrapper = ICSVFile(path)
     >>> wrapper
-    <waeup.csvfile.csvfile.CSVFile object at 0x...>
+    <waeup.sirp.csvfile.csvfile.CSVFile object at 0x...>
 
 This wrapper can return the CSV data as a sequence of dicts:
@@ -271,14 +271,14 @@
 use the :func:`getCSVFile` function:
 
-    >>> from waeup.csvfile.csvfile import getCSVFile
+    >>> from waeup.sirp.csvfile.csvfile import getCSVFile
     >>> wrapper = getCSVFile(path)
     >>> wrapper
-    <waeup.csvfile.csvfile.CSVFile object at 0x...>
+    <waeup.sirp.csvfile.csvfile.CSVFile object at 0x...>
 
 As we currently have only one type of wrapper, we get this. Let's
 create another wrapper, that requires a column 'col1':
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.csvfile import CSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile import CSVFile
     >>> class ICSVFileWithCol1(ICSVFile):
     ...   """A CSV file that contains a 'col1' column.
@@ -341,6 +341,6 @@
 in constructor, whether this requirement is met:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.csvfile import CSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile import CSVFile
     >>> class ICSVFile13(ICSVFile):
     ...   """A CSV file that contains a 'special_col' column.
@@ -370,6 +370,6 @@
 We create a wrapper that requires 'col1' and 'col2':
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.csvfile import CSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile import CSVFile
     >>> class ICSVFile12(ICSVFile):
     ...   """A CSV file that contains a 'special_col' column.
@@ -390,5 +390,5 @@
   path (i.e. __init__ raises some kind of exception): score is -1:
 
-    >>> from waeup.csvfile.csvfile import getScore
+    >>> from waeup.sirp.csvfile.csvfile import getScore
     >>> getScore('nonexistant', CSVFile)
     -1
@@ -426,6 +426,6 @@
 
     >>> import grok
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.csvfile import CSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile import CSVFile
 
     >>> class ICustomCSVFile(ICSVFile):
@@ -501,6 +501,6 @@
 Now we create a wrapper, that requires that field:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.csvfile import CSVFile
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.csvfile import CSVFile
     >>> class ICSVFileWithSpecialCol(ICSVFile):
     ...   """A CSV file that contains a 'special_col' column.
@@ -629,5 +629,5 @@
 before, using the :func:`getCSVFile` function:
 
-    >>> from waeup.csvfile import getCSVFile
+    >>> from waeup.sirp.csvfile import getCSVFile
     >>> myfile = getCSVFile(path)
     >>> ICSVFile12.providedBy(myfile)
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/__init__.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/__init__.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/__init__.py	(revision 4920)
@@ -1,3 +1,3 @@
 # Make this a package.
-from waeup.csvfile.csvfile import getCSVFile, CSVFile
-from waeup.csvfile.util import toBool
+from waeup.sirp.csvfile.csvfile import getCSVFile, CSVFile
+from waeup.sirp.csvfile.util import toBool
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/csvfile.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/csvfile.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/csvfile.py	(revision 4920)
@@ -6,5 +6,5 @@
 import csv
 import grok
-from waeup.csvfile.interfaces import ICSVFile
+from waeup.sirp.csvfile.interfaces import ICSVFile
 
 class CSVFile(grok.Adapter):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.py	(revision 4920)
@@ -12,9 +12,9 @@
 from zope.component import getMultiAdapter
 from zope.component.interfaces import ObjectEvent
-from waeup.csvfile import getCSVFile
-from waeup.interfaces import (IDataCenter, IWAeUPCSVImporter,
+from waeup.sirp.csvfile import getCSVFile
+from waeup.sirp.interfaces import (IDataCenter, IWAeUPCSVImporter,
                               ICSVDataReceivers, IDataCenterFile,
                               IDataCenterStorageMovedEvent)
-from waeup.utils.helpers import copyFileSystemTree
+from waeup.sirp.utils.helpers import copyFileSystemTree
 
 class DataCenter(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/datacenter.txt	(revision 4920)
@@ -11,8 +11,8 @@
 A data center can be created easily:
 
-    >>> from waeup.datacenter import DataCenter
+    >>> from waeup.sirp.datacenter import DataCenter
     >>> mydatacenter = DataCenter()
     >>> mydatacenter
-    <waeup.datacenter.DataCenter object at 0x...>
+    <waeup.sirp.datacenter.DataCenter object at 0x...>
 
 Each data center has a location in file system where files are stored:
@@ -20,5 +20,5 @@
     >>> storagepath = mydatacenter.storage
     >>> storagepath
-    '/.../src/waeup/files'
+    '/.../waeup/sirp/files'
 
 
@@ -77,5 +77,5 @@
 
     >>> mydatacenter.getFiles()
-    [<waeup.datacenter.DataCenterFile object at 0x...>]
+    [<waeup.sirp.datacenter.DataCenterFile object at 0x...>]
 
 As we can see, the actual file is wrapped by a convenience wrapper,
@@ -282,6 +282,6 @@
 
     >>> import grok
-    >>> from waeup.interfaces import ICSVDataReceivers
-    >>> from waeup.datacenter import DataCenter
+    >>> from waeup.sirp.interfaces import ICSVDataReceivers
+    >>> from waeup.sirp.datacenter import DataCenter
     >>> class SomeContainer(grok.Container):
     ...   grok.implements(ICSVDataReceivers)
@@ -302,7 +302,7 @@
 to import data into instances of MyCSVReceiver:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.interfaces import IWAeUPCSVImporter
-    >>> from waeup.utils.importexport import CSVImporter
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.interfaces import IWAeUPCSVImporter
+    >>> from waeup.sirp.utils.importexport import CSVImporter
     >>> class MyCSVImporter(CSVImporter):
     ...   grok.adapts(ICSVFile, MyCSVReceiver)
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostel.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostel.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostel.py	(revision 4920)
@@ -1,4 +1,4 @@
 import grok
-from waeup.interfaces import IHostel
+from waeup.sirp.interfaces import IHostel
 
 class Hostel(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.py	(revision 4920)
@@ -2,5 +2,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.interfaces import IHostelContainer, IHostel
+from waeup.sirp.interfaces import IHostelContainer, IHostel
 
 class HostelContainer(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/hostel/hostelcontainer.txt	(revision 4920)
@@ -1,4 +1,4 @@
-waeup.hostel.HostelContainer
-****************************
+waeup.sirp.hostel.HostelContainer
+*********************************
 
 Containers for hostels.
@@ -11,10 +11,10 @@
 We can easily create `HostelContainers`::
 
-    >>> from waeup.hostel.hostelcontainer import HostelContainer
+    >>> from waeup.sirp.hostel.hostelcontainer import HostelContainer
     >>> mycontainer = HostelContainer()
 
 Hostel containers provide ``IHostelContainer``:
 
-    >>> from waeup.interfaces import IHostelContainer
+    >>> from waeup.sirp.interfaces import IHostelContainer
     >>> IHostelContainer.providedBy(mycontainer)
     True
@@ -31,5 +31,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.HostelContainer')
-    <waeup.hostel.hostelcontainer.HostelContainer object at 0x...>
+    <waeup.sirp.hostel.hostelcontainer.HostelContainer object at 0x...>
 
 This way we get a thing that implements IHostelContainer without
@@ -57,5 +57,5 @@
 Okay, so we have to get a hostel first::
 
-    >>> from waeup.hostel.hostel import Hostel
+    >>> from waeup.sirp.hostel.hostel import Hostel
     >>> myhostel = Hostel()
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/interfaces.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/interfaces.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/interfaces.py	(revision 4920)
@@ -8,5 +8,5 @@
 from zope import schema
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
-from waeup.permissions import RoleSource
+from waeup.sirp.permissions import RoleSource
 
 class FatalCSVError(Exception):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/permissions.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/permissions.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/permissions.txt	(revision 4920)
@@ -16,5 +16,5 @@
 We can get all roles defined in a WAeUP portal:
 
-    >>> from waeup.permissions import getRoles
+    >>> from waeup.sirp.permissions import getRoles
     >>> getRoles()
     ['waeup.PortalManager', 'waeup.PortalUser']
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/student/student.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/student/student.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/student/student.py	(revision 4920)
@@ -1,5 +1,5 @@
 import grok
 from grok import index
-from waeup.student.interfaces import IStudent
+from waeup.sirp.student.interfaces import IStudent
 
 def fromCsv(a):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/student/studentcontainer.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/student/studentcontainer.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/student/studentcontainer.py	(revision 4920)
@@ -3,6 +3,6 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.interfaces import IStudentContainer
-from waeup.utils import importexport as csv
+from waeup.sirp.interfaces import IStudentContainer
+from waeup.sirp.utils import importexport as csv
 
 class StudentContainer(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/tables.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/tables.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/tables.py	(revision 4920)
@@ -2,9 +2,9 @@
 """
 import grok
-from waeup.interfaces import (IUniversity, IFacultyContainer, IFaculty,
+from waeup.sirp.interfaces import (IUniversity, IFacultyContainer, IFaculty,
                               IDepartment, ICourseContainer)
-from waeup.widgets.interfaces import ITableProvider
-from waeup.widgets.table import YUITable as Table
-from waeup.widgets.table import Col
+from waeup.sirp.widgets.interfaces import ITableProvider
+from waeup.sirp.widgets.table import YUITable as Table
+from waeup.sirp.widgets.table import Col
 from zope.security.management import checkPermission
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/testing.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/testing.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/testing.py	(revision 4920)
@@ -1,8 +1,8 @@
 import os.path
-import waeup
+import waeup.sirp
 from zope.app.testing.functional import ZCMLLayer
 
 ftesting_zcml = os.path.join(
-    os.path.dirname(waeup.__file__), 'ftesting.zcml')
+    os.path.dirname(waeup.sirp.__file__), 'ftesting.zcml')
 FunctionalLayer = ZCMLLayer(ftesting_zcml, __name__, 'FunctionalLayer',
                             allow_teardown=True)
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/tests/test_waeup.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/tests/test_waeup.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/tests/test_waeup.py	(revision 4920)
@@ -2,9 +2,9 @@
 ## test_waeuptest.py
 """
-Test setup for the waeup package.
+Test setup for the waeup.sirp package.
 """
 import grok
 import zope.component.eventtesting
-from waeup.testing import FunctionalLayer
+from waeup.sirp.testing import FunctionalLayer
 
 def setUpZope(test):
@@ -13,4 +13,4 @@
 # Register all tests in the waeup_ng package
 test_suite = grok.testing.register_all_tests(
-    'waeup', usetup=setUpZope,
+    'waeup.sirp', usetup=setUpZope,
     layer=FunctionalLayer)
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.py	(revision 4920)
@@ -7,5 +7,5 @@
 from zope.component.interfaces import IFactory, ComponentLookupError
 from zope.interface import implementedBy
-from waeup.interfaces import ICertificate, ICertificateCourse, ICourse
+from waeup.sirp.interfaces import ICertificate, ICertificateCourse, ICourse
 
 class Certificate(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificate.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.certificate` -- Certificates for WAeUP
-*************************************************************
-
-.. module:: waeup.university.certificate
+:mod:`waeup.sirp.university.certificate` -- Certificates for WAeUP
+******************************************************************
+
+.. module:: waeup.sirp.university.certificate
 
 Components that represent and manage certificates.
@@ -31,10 +31,10 @@
    All parameters are optional:
 
-     >>> from waeup.university.certificate import Certificate
+     >>> from waeup.sirp.university.certificate import Certificate
      >>> mycertificate = Certificate()
 
    Certificates have the attributes required by the `ICertificate` interface:
 
-     >>> from waeup.interfaces import ICertificate
+     >>> from waeup.sirp.interfaces import ICertificate
      >>> ICertificate.providedBy(mycertificate)
      True
@@ -164,8 +164,8 @@
 
       Add a reference to a course. A course is an object implementing
-      :class:`waeup.interfaces.ICourse`.
+      :class:`waeup.sirp.interfaces.ICourse`.
 
       Please don't be confused by the term 'reference'. This just
-      means an ordinary :class:`waeup.university.course.Course` object
+      means an ordinary :class:`waeup.sirp.university.course.Course` object
       in almost all cases. As this object will normaly be one stored
       in a department, the course here will simply become a reference
@@ -226,5 +226,5 @@
      >>> mycertificate = createObject(u'waeup.Certificate')
      >>> mycertificate
-     <waeup.university.certificate.Certificate object at 0x...>
+     <waeup.sirp.university.certificate.Certificate object at 0x...>
 
    The factory complies with the specifications from the
@@ -233,5 +233,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.certificate import CertificateFactory
+     >>> from waeup.sirp.university.certificate import CertificateFactory
      >>> verifyClass(IFactory, CertificateFactory)
      True
@@ -242,5 +242,5 @@
      >>> certificate_factory = CertificateFactory()
      >>> certificate_factory.getInterfaces()
-     <implementedBy waeup.university.certificate.Certificate>
+     <implementedBy waeup.sirp.university.certificate.Certificate>
 
 
@@ -260,5 +260,5 @@
      >>> mycertificatecourse = createObject(u'waeup.CertificateCourse')
      >>> mycertificatecourse
-     <waeup.university.certificate.CertificateCourse object at 0x...>
+     <waeup.sirp.university.certificate.CertificateCourse object at 0x...>
 
    The factory complies with the specifications from the
@@ -267,5 +267,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.certificate import CertificateCourseFactory
+     >>> from waeup.sirp.university.certificate import CertificateCourseFactory
      >>> verifyClass(IFactory, CertificateCourseFactory)
      True
@@ -276,5 +276,5 @@
      >>> certcourse_factory = CertificateCourseFactory()
      >>> certcourse_factory.getInterfaces()
-     <implementedBy waeup.university.certificate.CertificateCourse>
+     <implementedBy waeup.sirp.university.certificate.CertificateCourse>
 
 
@@ -311,8 +311,8 @@
 We can create certificates:
 
-    >>> from waeup.university.certificate import Certificate
+    >>> from waeup.sirp.university.certificate import Certificate
     >>> mycertificate = Certificate()
     >>> mycertificate
-    <waeup.university.certificate.Certificate object at 0x...>
+    <waeup.sirp.university.certificate.Certificate object at 0x...>
 
 Another way to create certificates is by asking for a factory called
@@ -323,5 +323,5 @@
     >>> mycertificate = createObject(u'waeup.Certificate')
     >>> mycertificate
-    <waeup.university.certificate.Certificate object at 0x...>
+    <waeup.sirp.university.certificate.Certificate object at 0x...>
 
 CertificateCourses
@@ -331,6 +331,6 @@
 :class:`ICertificateCourse` interface:
 
-    >>> from waeup.interfaces import ICertificateCourse
-    >>> from waeup.university.certificate import CertificateCourse
+    >>> from waeup.sirp.interfaces import ICertificateCourse
+    >>> from waeup.sirp.university.certificate import CertificateCourse
     >>> mycertcourse = CertificateCourse(None, 200, False)
     >>> ICertificateCourse.providedBy(mycertcourse)
@@ -347,5 +347,5 @@
     >>> mycertcourse = createObject(u'waeup.CertificateCourse')
     >>> mycertcourse
-    <waeup.university.certificate.CertificateCourse object at 0x...>
+    <waeup.sirp.university.certificate.CertificateCourse object at 0x...>
 
 .. _removecertificatecourses:
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.py	(revision 4920)
@@ -2,5 +2,5 @@
 """
 import grok
-from waeup.interfaces import ICertificateContainer, ICertificate
+from waeup.sirp.interfaces import ICertificateContainer, ICertificate
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/certificatecontainer.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.certificatecontainer` -- Certificate containers
-**********************************************************************
+:mod:`waeup.sirp.university.certificatecontainer` -- Certificate containers
+***************************************************************************
 
-.. module:: waeup.university.certificatecontainer
+.. module:: waeup.sirp.university.certificatecontainer
 
 Containers for certificates.
@@ -32,14 +32,14 @@
    :class:`CertificateContainer` instances are instances of
    :class:`grok.Container` that hold and manage instances of
-   :class:`waeup.university.certificate.Certificate`.
+   :class:`waeup.sirp.university.certificate.Certificate`.
 
-     >>> from waeup.university.certificatecontainer import CertificateContainer
+     >>> from waeup.sirp.university.certificatecontainer import CertificateContainer
      >>> mycontainer = CertificateContainer()
      >>> mycontainer
-     <waeup.university.certificatecontainer.CertificateContainer object at 0x...>
+     <waeup.sirp.university.certificatecontainer.CertificateContainer object at 0x...>
 
    Certificate containers provide `ICertificateContainer`:
 
-     >>> from waeup.interfaces import ICertificateContainer
+     >>> from waeup.sirp.interfaces import ICertificateContainer
      >>> ICertificateContainer.providedBy(mycontainer)
      True
@@ -63,7 +63,7 @@
 
       *certificate* must be an instance of
-      :class:`waeup.university.certificate.Certificate`:
+      :class:`waeup.sirp.university.certificate.Certificate`:
 
-        >>> from waeup.university.certificatecontainer import (
+        >>> from waeup.sirp.university.certificatecontainer import (
         ...   CertificateContainer)
         >>> mycontainer = CertificateContainer()
@@ -75,5 +75,5 @@
       The key of added items is the ``code`` attribute:
 
-        >>> from waeup.university.certificate import Certificate
+        >>> from waeup.sirp.university.certificate import Certificate
         >>> mycertificate = Certificate(code='CERTIFICATE1')
         >>> mycontainer.addCertificate(mycertificate)
@@ -110,5 +110,5 @@
      >>> mycertificatecontainer = createObject(u'waeup.CertificateContainer')
      >>> mycertificatecontainer
-     <waeup.university.certificatecontainer.CertificateContainer object at 0x...>
+     <waeup.sirp.university.certificatecontainer.CertificateContainer object at 0x...>
 
    The factory complies with the specifications from the
@@ -117,5 +117,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.certificatecontainer import (
+     >>> from waeup.sirp.university.certificatecontainer import (
      ...   CertificateContainerFactory)
      >>> verifyClass(IFactory, CertificateContainerFactory)
@@ -127,5 +127,5 @@
      >>> certificatecontainer_factory = CertificateContainerFactory()
      >>> certificatecontainer_factory.getInterfaces()
-     <implementedBy waeup.university.certificatecontainer.CertificateContainer>
+     <implementedBy waeup.sirp.university.certificatecontainer.CertificateContainer>
 
 
@@ -138,5 +138,5 @@
 We can easily create `CertificateContainers`:
 
-    >>> from waeup.university.certificatecontainer import CertificateContainer
+    >>> from waeup.sirp.university.certificatecontainer import CertificateContainer
     >>> mycontainer = CertificateContainer()
 
@@ -149,5 +149,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.CertificateContainer')
-    <waeup.university.certificatecontainer.CertificateContainer object at 0x...>
+    <waeup.sirp.university.certificatecontainer.CertificateContainer object at 0x...>
 
 This way we get a thing that implements ICertificateContainer without
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.py	(revision 4920)
@@ -4,5 +4,5 @@
 from zope.interface import implementedBy
 from zope.component.interfaces import IFactory
-from waeup.interfaces import ICourse
+from waeup.sirp.interfaces import ICourse
 
 class Course(grok.Model):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/course.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.course` -- Courses
-*****************************************
+:mod:`waeup.sirp.university.course` -- Courses
+**********************************************
 
-.. module:: waeup.university.course
+.. module:: waeup.sirp.university.course
 
 Components that represent courses.
@@ -30,13 +30,13 @@
    All parameters are optional:
 
-     >>> from waeup.university.course import Course
+     >>> from waeup.sirp.university.course import Course
      >>> mycourse = Course()
      >>> mycourse
-     <waeup.university.course.Course object at 0x...>
+     <waeup.sirp.university.course.Course object at 0x...>
 
    Course instances have the attributes required by the
-   :class:`waeup.interfaces.ICourse` interface:
+   :class:`waeup.sirp.interfaces.ICourse` interface:
 
-     >>> from waeup.interfaces import ICourse
+     >>> from waeup.sirp.interfaces import ICourse
      >>> ICourse.providedBy(mycourse)
      True
@@ -115,5 +115,5 @@
      >>> mycourse = createObject(u'waeup.Course')
      >>> mycourse
-     <waeup.university.course.Course object at 0x...>
+     <waeup.sirp.university.course.Course object at 0x...>
 
    The factory complies with the specifications from the
@@ -122,5 +122,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.course import CourseFactory
+     >>> from waeup.sirp.university.course import CourseFactory
      >>> verifyClass(IFactory, CourseFactory)
      True
@@ -131,5 +131,5 @@
      >>> course_factory = CourseFactory()
      >>> course_factory.getInterfaces()
-     <implementedBy waeup.university.course.Course>
+     <implementedBy waeup.sirp.university.course.Course>
 
 Examples
@@ -142,8 +142,8 @@
 class and calling the constructor:
 
-    >>> from waeup.university.course import Course
+    >>> from waeup.sirp.university.course import Course
     >>> mycourse = Course()
     >>> mycourse
-    <waeup.university.course.Course object at 0x...>
+    <waeup.sirp.university.course.Course object at 0x...>
 
 Another way to create courses is by asking for a factory called
@@ -154,4 +154,4 @@
     >>> mycourse = createObject(u'waeup.Course')
     >>> mycourse
-    <waeup.university.course.Course object at 0x...>
+    <waeup.sirp.university.course.Course object at 0x...>
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.py	(revision 4920)
@@ -4,5 +4,5 @@
 from zope.interface import implementedBy
 from zope.component.interfaces import IFactory
-from waeup.interfaces import ICourseContainer, ICourse
+from waeup.sirp.interfaces import ICourseContainer, ICourse
 
 class CourseContainer(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/coursecontainer.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.coursecontainer` -- Course containers
-************************************************************
+:mod:`waeup.sirp.university.coursecontainer` -- Course containers
+*****************************************************************
 
-.. module:: waeup.university.coursecontainer
+.. module:: waeup.sirp.university.coursecontainer
 
 Containers for courses.
@@ -32,14 +32,14 @@
    :class:`CourseContainer` instances are instances of
    :class:`grok.Container` that hold and manage instances of
-   :class:`waeup.university.course.Course`.
+   :class:`waeup.sirp.university.course.Course`.
 
-     >>> from waeup.university.coursecontainer import CourseContainer
+     >>> from waeup.sirp.university.coursecontainer import CourseContainer
      >>> mycontainer = CourseContainer()
      >>> mycontainer
-     <waeup.university.coursecontainer.CourseContainer object at 0x...>
+     <waeup.sirp.university.coursecontainer.CourseContainer object at 0x...>
 
    Course containers provide `ICourseContainer`:
 
-     >>> from waeup.interfaces import ICourseContainer
+     >>> from waeup.sirp.interfaces import ICourseContainer
      >>> ICourseContainer.providedBy(mycontainer)
      True
@@ -63,7 +63,7 @@
 
       *course* must be an instance of
-      :class:`waeup.university.course.Course`:
+      :class:`waeup.sirp.university.course.Course`:
 
-        >>> from waeup.university.coursecontainer import CourseContainer
+        >>> from waeup.sirp.university.coursecontainer import CourseContainer
         >>> mycontainer = CourseContainer()
         >>> mycontainer.addCourse('blah')
@@ -74,5 +74,5 @@
       The key of added items is the ``code`` attribute:
 
-        >>> from waeup.university.course import Course
+        >>> from waeup.sirp.university.course import Course
         >>> mycourse = Course(code='COURSE1')
         >>> mycontainer.addCourse(mycourse)
@@ -109,5 +109,5 @@
      >>> mycoursecontainer = createObject(u'waeup.CourseContainer')
      >>> mycoursecontainer
-     <waeup.university.coursecontainer.CourseContainer object at 0x...>
+     <waeup.sirp.university.coursecontainer.CourseContainer object at 0x...>
 
    The factory complies with the specifications from the
@@ -116,5 +116,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.coursecontainer import CourseContainerFactory
+     >>> from waeup.sirp.university.coursecontainer import CourseContainerFactory
      >>> verifyClass(IFactory, CourseContainerFactory)
      True
@@ -125,5 +125,5 @@
      >>> coursecontainer_factory = CourseContainerFactory()
      >>> coursecontainer_factory.getInterfaces()
-     <implementedBy waeup.university.coursecontainer.CourseContainer>
+     <implementedBy waeup.sirp.university.coursecontainer.CourseContainer>
 
 
@@ -136,5 +136,5 @@
 We can easily create `CourseContainers`:
 
-    >>> from waeup.university.coursecontainer import CourseContainer
+    >>> from waeup.sirp.university.coursecontainer import CourseContainer
     >>> mycontainer = CourseContainer()
 
@@ -147,5 +147,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.CourseContainer')
-    <waeup.university.coursecontainer.CourseContainer object at 0x...>
+    <waeup.sirp.university.coursecontainer.CourseContainer object at 0x...>
 
 This way we get a thing that implements ICourseContainer without
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.py	(revision 4920)
@@ -5,5 +5,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.interfaces import IDepartment
+from waeup.sirp.interfaces import IDepartment
 
 class Department(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/department.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.department` -- Departments
-*************************************************
+:mod:`waeup.sirp.university.department` -- Departments
+******************************************************
 
-.. module:: waeup.university.department
+.. module:: waeup.sirp.university.department
 
 Components that represent university departments.
@@ -26,11 +26,11 @@
    Create a representation of a university department:
 
-     >>> from waeup.university.department import Department
+     >>> from waeup.sirp.university.department import Department
      >>> mydept = Department()
      >>> mydept
-     <waeup.university.department.Department object at 0x...>
+     <waeup.sirp.university.department.Department object at 0x...>
 
    Another way to create :class:`Department` instances is by asking
-   for a factory called ``waeup.Department``. This way we can create a
+   for a factory called ``waeup.sirp.Department``. This way we can create a
    department without importing a class:
 
@@ -38,10 +38,10 @@
      >>> mydept = createObject(u'waeup.Department')
      >>> mydept
-     <waeup.university.department.Department object at 0x...>
+     <waeup.sirp.university.department.Department object at 0x...>
 
    :class:`Department` instances have the attributes required by the
    `IDepartment` interface:
 
-     >>> from waeup.interfaces import IDepartment
+     >>> from waeup.sirp.interfaces import IDepartment
      >>> IDepartment.providedBy(mydept)
      True
@@ -92,5 +92,5 @@
 
         >>> mydept.courses
-        <waeup.university.coursecontainer.CourseContainer object at 0x...>
+        <waeup.sirp.university.coursecontainer.CourseContainer object at 0x...>
 
 
@@ -103,5 +103,5 @@
 
         >>> mydept.certificates
-        <waeup...certificatecontainer.CertificateContainer object at 0x...>
+        <waeup.sirp...certificatecontainer.CertificateContainer object at 0x...>
 
 Utilities
@@ -123,5 +123,5 @@
      >>> mydepartment = createObject(u'waeup.Department')
      >>> mydepartment
-     <waeup.university.department.Department object at 0x...>
+     <waeup.sirp.university.department.Department object at 0x...>
 
    The factory complies with the specifications from the
@@ -130,5 +130,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.department import DepartmentFactory
+     >>> from waeup.sirp.university.department import DepartmentFactory
      >>> verifyClass(IFactory, DepartmentFactory)
      True
@@ -139,3 +139,3 @@
      >>> department_factory = DepartmentFactory()
      >>> department_factory.getInterfaces()
-     <implementedBy waeup.university.department.Department>
+     <implementedBy waeup.sirp.university.department.Department>
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.py	(revision 4920)
@@ -5,5 +5,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.interfaces import IFaculty, IDepartment
+from waeup.sirp.interfaces import IFaculty, IDepartment
 
 class Faculty(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/faculty.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.university.faculty` -- Faculties
-********************************************
-
-.. module:: waeup.university.faculty
+:mod:`waeup.sirp.university.faculty` -- Faculties
+*************************************************
+
+.. module:: waeup.sirp.university.faculty
 
 Components that represent university faculties.
@@ -25,8 +25,8 @@
    Create a representation of a university faculty:
 
-     >>> from waeup.university.faculty import Faculty
+     >>> from waeup.sirp.university.faculty import Faculty
      >>> myfac = Faculty()
      >>> myfac
-     <waeup.university.faculty.Faculty object at 0x...>
+     <waeup.sirp.university.faculty.Faculty object at 0x...>
 
    Another way to create :class:`Faculty` instances is by asking
@@ -37,10 +37,10 @@
      >>> myfac = createObject(u'waeup.Faculty')
      >>> myfac
-     <waeup.university.faculty.Faculty object at 0x...>
+     <waeup.sirp.university.faculty.Faculty object at 0x...>
 
    :class:`Faculty` instances have the attributes required by the
    `IFaculty` interface:
 
-     >>> from waeup.interfaces import IFaculty
+     >>> from waeup.sirp.interfaces import IFaculty
      >>> IFaculty.providedBy(myfac)
      True
@@ -66,10 +66,10 @@
       Regular departments are accepted:
 
-        >>> from waeup.university.department import Department
+        >>> from waeup.sirp.university.department import Department
         >>> myfac.addDepartment(Department(title='Physics',
         ...                                code='DP'))
 
         >>> list(myfac.items())
-        [(u'DP', <waeup.university.department.Department object at 0x...>)]
+        [(u'DP', <waeup.sirp.university.department.Department object at 0x...>)]
 
    .. method:: clear()
@@ -132,5 +132,5 @@
      >>> myfaculty = createObject(u'waeup.Faculty')
      >>> myfaculty
-     <waeup.university.faculty.Faculty object at 0x...>
+     <waeup.sirp.university.faculty.Faculty object at 0x...>
 
    The factory complies with the specifications from the
@@ -139,5 +139,5 @@
      >>> from zope.interface.verify import verifyClass
      >>> from zope.component.interfaces import IFactory
-     >>> from waeup.university.faculty import FacultyFactory
+     >>> from waeup.sirp.university.faculty import FacultyFactory
      >>> verifyClass(IFactory, FacultyFactory)
      True
@@ -148,5 +148,5 @@
      >>> faculty_factory = FacultyFactory()
      >>> faculty_factory.getInterfaces()
-     <implementedBy waeup.university.faculty.Faculty>
+     <implementedBy waeup.sirp.university.faculty.Faculty>
 
 
@@ -156,8 +156,8 @@
 We can create faculties:
 
-    >>> from waeup.university.faculty import Faculty
+    >>> from waeup.sirp.university.faculty import Faculty
     >>> myfaculty = Faculty()
     >>> myfaculty
-    <waeup.university.faculty.Faculty object at 0x...>
+    <waeup.sirp.university.faculty.Faculty object at 0x...>
 
 Another way to create faculties is by asking for a factory called
@@ -168,5 +168,5 @@
     >>> myfaculty = createObject(u'waeup.Faculty')
     >>> myfaculty
-    <waeup.university.faculty.Faculty object at 0x...>
+    <waeup.sirp.university.faculty.Faculty object at 0x...>
 
 Faculty attributes
@@ -175,5 +175,5 @@
 Faculties have the attributes required by the `IFaculty` interface:
 
-    >>> from waeup.interfaces import IFaculty
+    >>> from waeup.sirp.interfaces import IFaculty
     >>> IFaculty.providedBy(myfaculty)
     True
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.py	(revision 4920)
@@ -2,5 +2,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.interfaces import IFacultyContainer, IFaculty
+from waeup.sirp.interfaces import IFacultyContainer, IFaculty
 
 class FacultyContainer(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/university/facultycontainer.txt	(revision 4920)
@@ -11,10 +11,10 @@
 We can easily create `FacultyContainers`::
 
-    >>> from waeup.university.facultycontainer import FacultyContainer
+    >>> from waeup.sirp.university.facultycontainer import FacultyContainer
     >>> mycontainer = FacultyContainer()
 
 Faculty containers provide `IFacultyContainer`:
 
-    >>> from waeup.interfaces import IFacultyContainer
+    >>> from waeup.sirp.interfaces import IFacultyContainer
     >>> IFacultyContainer.providedBy(mycontainer)
     True
@@ -31,5 +31,5 @@
     >>> from zope.component import createObject
     >>> createObject(u'waeup.FacultyContainer')
-    <waeup.university.facultycontainer.FacultyContainer object at 0x...>
+    <waeup.sirp.university.facultycontainer.FacultyContainer object at 0x...>
 
 This way we get a thing that implements IFacultyContainer without
@@ -57,5 +57,5 @@
 Okay, so we have to get a faculty first::
 
-    >>> from waeup.university.faculty import Faculty
+    >>> from waeup.sirp.university.faculty import Faculty
     >>> myfaculty = Faculty()
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/users.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/users.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/users.py	(revision 4920)
@@ -2,6 +2,6 @@
 """
 import grok
-from waeup.authentication import Account
-from waeup.interfaces import IUserContainer
+from waeup.sirp.authentication import Account
+from waeup.sirp.interfaces import IUserContainer
 
 class UserContainer(grok.Container):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/users.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/users.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/users.txt	(revision 4920)
@@ -16,5 +16,5 @@
 us:
 
-    >>> from waeup.users import UserContainer
+    >>> from waeup.sirp.users import UserContainer
     >>> myusers = UserContainer()
 
@@ -33,5 +33,5 @@
     >>> bob = myusers['bob']
     >>> bob
-    <waeup.authentication.Account object at 0x...>
+    <waeup.sirp.authentication.Account object at 0x...>
 
     >>> bob.name
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/batching.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/batching.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/batching.py	(revision 4920)
@@ -15,5 +15,5 @@
 from zope.schema import getFields
 from zope.schema.interfaces import IText
-from waeup.interfaces import (IBatchProcessor, IFacultyContainer, IFaculty,
+from waeup.sirp.interfaces import (IBatchProcessor, IFacultyContainer, IFaculty,
                               ICourse, IDepartment, ICertificate,
                               ICertificateCourse, ISchemaTypeConverter,
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.py	(revision 4920)
@@ -9,5 +9,5 @@
     from zope.browser.interfaces import ITerms
 from zope.schema.interfaces import IBool, IText, IInt, IChoice
-from waeup.interfaces import ISchemaTypeConverter
+from waeup.sirp.interfaces import ISchemaTypeConverter
 
 # If a string has this value, it is considered as 'missing_value' or None.
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/converters.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.utils.converters` -- Converters
-*******************************************
-
-.. module:: waeup.utils.converters
+:mod:`waeup.sirp.utils.converters` -- Converters
+************************************************
+
+.. module:: waeup.sirp.utils.converters
 
 Converters for :mod:`zope.schema` based data.
@@ -25,5 +25,5 @@
    'non-values'. Current setting is:
 
-      >>> from waeup.utils.converters import NONE_STRING_VALUE
+      >>> from waeup.sirp.utils.converters import NONE_STRING_VALUE
       >>> NONE_STRING_VALUE
       ''
@@ -36,5 +36,5 @@
 ========
 
-The :mod:`waeup.utils.converters` module is basically a collection of
+The :mod:`waeup.sirp.utils.converters` module is basically a collection of
 adapters for field types of :mod:`zope.schema`.
 
@@ -52,5 +52,5 @@
    `zope.schema.Choice` or similar.
 
-   .. method:: provides(waeup.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
 
    .. method:: _convertValueFromString(string)
@@ -115,5 +115,5 @@
    .. method:: adapts(zope.schema.IText)
 
-   .. method:: provides(waeup.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -154,5 +154,5 @@
    .. method:: adapts(zope.schema.IBool)
 
-   .. method:: provides(waeup.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -195,5 +195,5 @@
    .. method:: adapts(zope.schema.IInt)
 
-   .. method:: provides(waeup.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -236,5 +236,5 @@
    .. method:: adapts(zope.schema.IChoice)
 
-   .. method:: provides(waeup.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=False])
@@ -290,10 +290,10 @@
 :class:`TextConverter` instance:
 
-    >>> from waeup.utils.converters import TextConverter
+    >>> from waeup.sirp.utils.converters import TextConverter
     >>> converter = TextConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.interfaces import ISchemaTypeConverter
+    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -301,5 +301,5 @@
 
     >>> converter
-    <waeup.utils.converters.TextConverter object at 0x...>
+    <waeup.sirp.utils.converters.TextConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -378,10 +378,10 @@
 :class:`BoolConverter` instance:
 
-    >>> from waeup.utils.converters import BoolConverter
+    >>> from waeup.sirp.utils.converters import BoolConverter
     >>> converter = BoolConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.interfaces import ISchemaTypeConverter
+    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -389,5 +389,5 @@
 
     >>> converter
-    <waeup.utils.converters.BoolConverter object at 0x...>
+    <waeup.sirp.utils.converters.BoolConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -490,10 +490,10 @@
 :class:`IntConverter` instance:
 
-    >>> from waeup.utils.converters import IntConverter
+    >>> from waeup.sirp.utils.converters import IntConverter
     >>> converter = IntConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.interfaces import ISchemaTypeConverter
+    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -501,5 +501,5 @@
 
     >>> converter
-    <waeup.utils.converters.IntConverter object at 0x...>
+    <waeup.sirp.utils.converters.IntConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -593,10 +593,10 @@
 :class:`ChoiceConverter` instance:
 
-    >>> from waeup.utils.converters import ChoiceConverter
+    >>> from waeup.sirp.utils.converters import ChoiceConverter
     >>> converter = ChoiceConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.interfaces import ISchemaTypeConverter
+    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -604,5 +604,5 @@
 
     >>> converter
-    <waeup.utils.converters.ChoiceConverter object at 0x...>
+    <waeup.sirp.utils.converters.ChoiceConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -668,5 +668,5 @@
     '1'
 
-    >>> from waeup.interfaces import ICourse
+    >>> from waeup.sirp.interfaces import ICourse
     >>> from zope.schema import getFields
     >>> field = getFields(ICourse)['semester']
@@ -720,5 +720,5 @@
 
 We get a converter for this field in the usual way. The
-:meth:`waeup.utils.converters.fromString()` method will return one of
+:meth:`waeup.sirp.utils.converters.fromString()` method will return one of
 the objects if we feed it with ``'Wilma'`` or ``'Fred'``:
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.py	(revision 4920)
@@ -2,8 +2,8 @@
 """
 import grok
-from waeup.csvfile import CSVFile, toBool
-from waeup.csvfile.interfaces import ICSVFile
-from waeup.interfaces import IFacultyContainer, IWAeUPCSVImporter
-from waeup.utils.importexport import CSVImporter
+from waeup.sirp.csvfile import CSVFile, toBool
+from waeup.sirp.csvfile.interfaces import ICSVFile
+from waeup.sirp.interfaces import IFacultyContainer, IWAeUPCSVImporter
+from waeup.sirp.utils.importexport import CSVImporter
 from zope.app.catalog.interfaces import ICatalog
 from zope.component import createObject, getUtility
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/csvimport.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.utils.csvimport` -- CSV file importers
-**************************************************
+:mod:`waeup.sirp.utils.csvimport` -- CSV file importers
+*******************************************************
 
-.. module:: waeup.utils.csvimport
+.. module:: waeup.sirp.utils.csvimport
 
 Components for importing CSV files.
@@ -21,5 +21,5 @@
 data afterwards:
 
-    >>> from waeup.university.facultycontainer import FacultyContainer
+    >>> from waeup.sirp.university.facultycontainer import FacultyContainer
     >>> mycontainer = FacultyContainer()
 
@@ -35,8 +35,8 @@
 We get a suitable importer by asking for a multi-adapter to
 our file and IWAeUPCSVExporter (see section above, the importexport
-module and the `waeup.csvfile` README for details):
+module and the `waeup.sirp.csvfile` README for details):
 
-    >>> from waeup.csvfile import getCSVFile
-    >>> from waeup.interfaces import IWAeUPCSVImporter
+    >>> from waeup.sirp.csvfile import getCSVFile
+    >>> from waeup.sirp.interfaces import IWAeUPCSVImporter
     >>> from zope.component import getMultiAdapter
     >>> importer = getMultiAdapter((getCSVFile('myfaculties.csv'), 
@@ -44,9 +44,9 @@
     ...                            IWAeUPCSVImporter)
     >>> importer
-    <waeup.utils.csvimport.FacultyCSVImporter object at 0x...>
+    <waeup.sirp.utils.csvimport.FacultyCSVImporter object at 0x...>
 
 This importer complies with the IWAeUPCSVImporter interface:
 
-    >>> from waeup.utils.csvimport import FacultyCSVImporter
+    >>> from waeup.sirp.utils.csvimport import FacultyCSVImporter
     >>> IWAeUPCSVImporter.implementedBy(FacultyCSVImporter)
     True
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/helpers.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/helpers.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/helpers.txt	(revision 4920)
@@ -1,6 +1,6 @@
-:mod:`waeup.utils.helpers` -- Helpers for the WAeUP SRP
-*******************************************************
-
-.. module:: waeup.utils.helpers
+:mod:`waeup.sirp.utils.helpers` -- Helpers for the WAeUP SRP
+************************************************************
+
+.. module:: waeup.sirp.utils.helpers
 
 Helper functions for the WAeUP SRP.
@@ -16,5 +16,5 @@
 
      >>> import os
-     >>> from waeup.utils.helpers import removeFileOrDirectory
+     >>> from waeup.sirp.utils.helpers import removeFileOrDirectory
      >>> open('blah', 'wb').write('nonsense')
      >>> 'blah' in os.listdir('.')
@@ -67,5 +67,5 @@
      >>> open(os.path.join('src', 'blah'), 'wb').write('nonsense')
 
-     >>> from waeup.utils.helpers import copyFileSystemTree
+     >>> from waeup.sirp.utils.helpers import copyFileSystemTree
      >>> result = copyFileSystemTree('src', 'dst')
 
@@ -172,5 +172,5 @@
    returned with all preceeding/following stuff stripped:
 
-     >>> from waeup.utils.helpers import getInnerHTMLPart
+     >>> from waeup.sirp.utils.helpers import getInnerHTMLPart
      >>> print getInnerHTMLPart("""<html>
      ... <head>
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.py	(revision 4920)
@@ -7,6 +7,6 @@
 from xml.dom.minidom import Document, getDOMImplementation
 from zope.interface import Interface
-from waeup.csvfile.interfaces import ICSVFile
-from waeup.interfaces import (IWAeUPObject, IWAeUPExporter, IWAeUPXMLExporter,
+from waeup.sirp.csvfile.interfaces import ICSVFile
+from waeup.sirp.interfaces import (IWAeUPObject, IWAeUPExporter, IWAeUPXMLExporter,
                               IWAeUPXMLImporter, IWAeUPCSVImporter)
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/utils/importexport.txt	(revision 4920)
@@ -33,5 +33,5 @@
 We can export faculties. First we create a faculty::
 
-    >>> from waeup.university.faculty import Faculty
+    >>> from waeup.sirp.university.faculty import Faculty
     >>> myfaculty = Faculty()
     >>> myfaculty.name = 'My very faculty.'
@@ -43,8 +43,8 @@
 an exporter::
 
-    >>> from waeup.interfaces import IWAeUPXMLExporter
+    >>> from waeup.sirp.interfaces import IWAeUPXMLExporter
     >>> exporter = IWAeUPXMLExporter(myfaculty)
     >>> exporter
-    <waeup.utils.importexport.XMLExporter object at 0x...>
+    <waeup.sirp.utils.importexport.XMLExporter object at 0x...>
 
 All exporters provide an ``export(<obj>)`` method::
@@ -85,5 +85,5 @@
 afterwards::
 
-    >>> from waeup.university.faculty import Faculty
+    >>> from waeup.sirp.university.faculty import Faculty
     >>> myfaculty = Faculty()
     >>> myfaculty.name = 'My very faculty.'
@@ -91,5 +91,5 @@
 We create an XML dump of this object::
 
-    >>> from waeup.interfaces import IWAeUPXMLExporter
+    >>> from waeup.sirp.interfaces import IWAeUPXMLExporter
     >>> exporter = IWAeUPXMLExporter(myfaculty)
     >>> result = exporter.export('myexport.xml')
@@ -101,5 +101,5 @@
 Now we create an importer for that file::
 
-    >>> from waeup.interfaces import IWAeUPXMLImporter
+    >>> from waeup.sirp.interfaces import IWAeUPXMLImporter
     >>> importer = IWAeUPXMLImporter(myfaculty)
 
@@ -114,5 +114,5 @@
 
     >>> new_obj
-    <waeup.university.faculty.Faculty object at 0x...>
+    <waeup.sirp.university.faculty.Faculty object at 0x...>
 
     >>> new_obj.name
@@ -135,5 +135,5 @@
 
     >>> new_obj
-    <waeup.university.faculty.Faculty object at 0x...>
+    <waeup.sirp.university.faculty.Faculty object at 0x...>
 
 Clean up::
@@ -158,8 +158,8 @@
 
 CSV sources build a plugin framework inside the WAeUP portal (that
-might be factored out one day). See `waeup.csvfile` to learn more
+might be factored out one day). See `waeup.sirp.csvfile` to learn more
 about that.
 
-A `waeup.csvfile.CSVFile` plugin cares for a special kind of CSV file.
+A `waeup.sirp.csvfile.CSVFile` plugin cares for a special kind of CSV file.
 
 To make clear what that means, we start by creating a simple CSV
@@ -186,8 +186,8 @@
 a file:
 
-    >>> from waeup.csvfile import getCSVFile
+    >>> from waeup.sirp.csvfile import getCSVFile
     >>> mysource = getCSVFile('mycavedata.csv')
     >>> mysource
-    <waeup.csvfile.csvfile.CSVFile object at 0x...>
+    <waeup.sirp.csvfile.csvfile.CSVFile object at 0x...>
 
 We define caves like this:
@@ -218,7 +218,7 @@
 importer, that imports data to the container:
 
-    >>> from waeup.csvfile.interfaces import ICSVFile
-    >>> from waeup.utils.importexport import CSVImporter
-    >>> from waeup.interfaces import IWAeUPCSVImporter
+    >>> from waeup.sirp.csvfile.interfaces import ICSVFile
+    >>> from waeup.sirp.utils.importexport import CSVImporter
+    >>> from waeup.sirp.interfaces import IWAeUPCSVImporter
     >>> class CaveImporter(CSVImporter):
     ...   # Tell, what kinds of objects we connect...
@@ -268,5 +268,5 @@
   adapting this instead of ICSVData.
 
-  In the `waeup.csvfile` subpackage's README it is shown, how this can
+  In the `waeup.sirp.csvfile` subpackage's README it is shown, how this can
   be accomplished.
 
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.py	(revision 4920)
@@ -4,5 +4,5 @@
 from hurry import yui
 from zope.interface import Interface
-from waeup.widgets.interfaces import ITableProvider
+from waeup.sirp.widgets.interfaces import ITableProvider
 
 def varName(string):
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.txt
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.txt	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/widgets/table.txt	(revision 4920)
@@ -1,4 +1,4 @@
-waeup.widgets
-*************
+waeup.sirp.widgets
+******************
 
 Widgets for the WAeUP SRP.
@@ -10,5 +10,5 @@
 ======
 
-    >>> from waeup.widgets.table import Col, Table
+    >>> from waeup.sirp.widgets.table import Col, Table
     >>> id = Col(
     ...       header='Id', width=100, sortable=True, type='int',
@@ -45,5 +45,5 @@
 
 
-    >>> from waeup.widgets.table import YUITable
+    >>> from waeup.sirp.widgets.table import YUITable
     >>> table = YUITable('My YUI Table', cols=(id, mycol1, mycol2))
     >>> print table.getJSTableCode()
@@ -75,5 +75,5 @@
 of object. The YUIStaticTableView looks up such an adapter for a given
 context to find a table to manage. The adapter has to implement
-`ITableProvider` from `waeup.widgets.interfaces` and should provide a
+`ITableProvider` from `waeup.sirp.widgets.interfaces` and should provide a
 `getTables` method.
 
@@ -82,5 +82,5 @@
     >>> import grok
     >>> grok.testing.grok('waeup')
-    >>> from waeup.widgets.interfaces import ITableProvider
+    >>> from waeup.sirp.widgets.interfaces import ITableProvider
     >>> class TableAdapter(grok.Adapter):
     ...   grok.context(SomeContent)
@@ -102,5 +102,5 @@
     ...                        name='yuistatictables.js')
     >>> view
-    <waeup.widgets.table.YUIStaticTableView object at 0x...>
+    <waeup.sirp.widgets.table.YUIStaticTableView object at 0x...>
 
 When we call the view we get pure JavaScript:
@@ -126,5 +126,5 @@
     ...                        name='yuistatictables.js')
     >>> view
-    <waeup.widgets.table.YUIStaticTableView object at 0x...>
+    <waeup.sirp.widgets.table.YUIStaticTableView object at 0x...>
 
 But if we call this adapter, we will get an empty result, because
Index: /waeup/branches/ulif-namespace/src/waeup/sirp/workflow.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/workflow.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/workflow.py	(revision 4920)
@@ -7,5 +7,5 @@
 from hurry.workflow.interfaces import IWorkflow, IWorkflowState, IWorkflowInfo
 from hurry.workflow.interfaces import IWorkflowVersions
-from waeup.interfaces import IWAeUPObject
+from waeup.sirp.interfaces import IWAeUPObject
 
 UNCHECKED = 'unchecked'

Index: /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/meta.py
===================================================================
--- /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/meta.py	(revision 4919)
+++ /waeup/branches/ulif-namespace/src/waeup/sirp/csvfile/meta.py	(revision 4920)
@@ -1,7 +1,7 @@
 """Meta configuration for waeup.csvfile components.
 """
 import martian
-import waeup.csvfile.csvfile
-from waeup.csvfile import CSVFile
+import waeup.sirp.csvfile.csvfile
+from waeup.sirp.csvfile import CSVFile
 
 # This grokker fills the registry on startup, with any class that is
@@ -10,4 +10,4 @@
     martian.component(CSVFile)
     def execute(self, klass, **kw):
-        waeup.csvfile.csvfile.csvwrappers.append(klass)
+        waeup.sirp.csvfile.csvfile.csvwrappers.append(klass)
         return True
@@ -1,7 +1,7 @@
-"""Meta configuration for waeup.csvfile components.
+"""Meta configuration for waeup.sirp.csvfile components.
 """
 import martian